### *easyPythonpi*

### >Add new methods to easyPythonpi.py file only

*A simple pyhton library for the beginners. The program includes simple calulations. Made for raising pull requests.*
Only simple functions are used to make the code beginner friendly :)

1. Fork this repository by click the Fork button in the top right of this page or simply [click here](https://github.com/extinctsion/easyPy/fork).
2. Once it is forked, clone the repository in your computer. For this, copy the URL in the address bar, and use the following command:

```sh
git clone url_you_just_copied
```

4. Open this cloned repository in your preferred code editor as shown below. Also, open a terminal in this directory.
(Use this command if you are using Linux distribution)

```sh
cd easyPythonpi
```

5. Now type in the following command in the terminal and replace `username` with your GitHub username. (This command is necessary or it will prompt errors.)

```sh
git checkout -b username
```


6. Inert new functions to the code.
```
    Your code appear here
```

7. Once you have done all this, commit your changes to GitHub. You can do this with the following commands. Make sure you execute them in the precise order one after another in your terminal.

```sh
# copy and paste the following in the terminal
git add .

# copy and paste the following in the terminal after you have executed the previous command
git commit -m "hacktoberfest contribution"

# copy and paste the following in the terminal after you have executed the previous command
git push -u origin your_github_username
```

8. Now open the forked repository on your GitHub. You will see a yellow box at the top telling you that some changes are pushed. You will also see a button called `Compare & pull request`. Click on it.
9. Now add a title, some description! 
   You have successfully opened a pull request in this repository.

*You need to open **four** valid pull requests in order to complete the challenge. If you have performed the above steps, you have already opened one pull request. And you need only three more.*

<br>

>Note: Those repositories who have `hacktoberfest` as a label are considered for Hacktoberfest challenge only.

Thanks for contributing to the Open source community.
